<?php

/*
 * This file is part of the Sonata Project package.
 *
 * (c) Thomas Rabaix <thomas.rabaix@sonata-project.org>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace ByDedi\AdminBundle\Builder;

use Doctrine\ORM\Mapping\ClassMetadataInfo;
use Sonata\AdminBundle\Admin\AdminInterface;
use Sonata\AdminBundle\Admin\FieldDescriptionCollection;
use Sonata\AdminBundle\Admin\FieldDescriptionInterface;
use Sonata\AdminBundle\Builder\ShowBuilderInterface;
use Sonata\AdminBundle\Guesser\TypeGuesserInterface;
use Sonata\CoreBundle\Form\Type\DatePickerType;
use Sonata\DoctrineORMAdminBundle\Builder\ShowBuilder as BaseShowBuilder;

class ShowBuilder extends BaseShowBuilder
{
    /**
     * {@inheritdoc}
     */
    public function fixFieldDescription(AdminInterface $admin, FieldDescriptionInterface $fieldDescription)
    {
        switch ($fieldDescription->getMappingType()) {
            case ClassMetadataInfo::MANY_TO_ONE:
                $fieldDescription->setTemplate('AdminBundle:admin/CRUD:show_orm_many_to_one.html.twig');
                break;
            case ClassMetadataInfo::ONE_TO_ONE:
                $fieldDescription->setTemplate('AdminBundle:admin/CRUD:show_orm_one_to_one.html.twig');
                break;
            case ClassMetadataInfo::ONE_TO_MANY:
                $fieldDescription->setTemplate('AdminBundle:admin/CRUD:show_orm_one_to_many.html.twig');
                break;
            case ClassMetadataInfo::MANY_TO_MANY:
                $fieldDescription->setTemplate('AdminBundle:admin/CRUD:show_orm_many_to_many.html.twig');
                break;
        }

        parent::fixFieldDescription($admin, $fieldDescription);

        if (null == $fieldDescription->getTemplate()) {
            switch ($fieldDescription->getType()) {
                case DatePickerType::class:
                    $fieldDescription->setTemplate('AdminBundle:admin/CRUD:show_date.html.twig');
                    break;
            }
        }

        switch ($fieldDescription->getMappingType()) {
            case ClassMetadataInfo::MANY_TO_ONE:
            case ClassMetadataInfo::ONE_TO_ONE:
            case ClassMetadataInfo::ONE_TO_MANY:
            case ClassMetadataInfo::MANY_TO_MANY:
                $admin->attachAdminClass($fieldDescription);
                break;
        }
    }
}
